@@ -6,7 +6,6 @@
  * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
-
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -30,10 +29,12 @@ static void debug_table_usage(struct state *state)
 	fprintf(stderr, " \t -w [interval] watch mode - refresh the table continuously\n");
 
 	if (debug_table->option_timeout_interval)
-		fprintf(stderr, " \t -t timeout interval - don't print originators not seen for x.y seconds \n");
+		fprintf(stderr,
+			" \t -t timeout interval - don't print originators not seen for x.y seconds\n");
 
 	if (debug_table->option_orig_iface)
-		fprintf(stderr, " \t -i [interface] - show multiif originator table for a specific interface\n");
+		fprintf(stderr,
+			" \t -i [interface] - show multiif originator table for a specific interface\n");
 
 	if (debug_table->option_unicast_only)
 		fprintf(stderr, " \t -u print unicast mac addresses only\n");
@@ -45,10 +46,11 @@ static void debug_table_usage(struct state *state)
 int handle_debug_table(struct state *state, int argc, char **argv)
 {
 	struct debug_table_data *debug_table = state->cmd->arg;
-	int optchar, read_opt = USE_BAT_HOSTS;
-	char *orig_iface = NULL;
+	int read_opt = USE_BAT_HOSTS;
 	float orig_timeout = 0.0f;
 	float watch_interval = 1;
+	char *orig_iface = NULL;
+	int optchar;
 	int err;
 
 	while ((optchar = getopt(argc, argv, "hnw:t:Humi:")) != -1) {
@@ -67,7 +69,9 @@ int handle_debug_table(struct state *state, int argc, char **argv)
 			}
 
 			if (!sscanf(optarg, "%f", &watch_interval)) {
-				fprintf(stderr, "Error - provided argument of '-%c' is not a number\n", optchar);
+				fprintf(stderr,
+					"Error - provided argument of '-%c' is not a number\n",
+	    optchar);
 				return EXIT_FAILURE;
 			}
 			break;
@@ -80,7 +84,9 @@ int handle_debug_table(struct state *state, int argc, char **argv)
 
 			read_opt |= NO_OLD_ORIGS;
 			if (!sscanf(optarg, "%f", &orig_timeout)) {
-				fprintf(stderr, "Error - provided argument of '-%c' is not a number\n", optchar);
+				fprintf(stderr,
+					"Error - provided argument of '-%c' is not a number\n",
+	    optchar);
 				return EXIT_FAILURE;
 			}
 			break;
@@ -119,15 +125,17 @@ int handle_debug_table(struct state *state, int argc, char **argv)
 			break;
 		case '?':
 			if (optopt == 't') {
-				fprintf(stderr, "Error - option '-t' needs a number as argument\n");
+				fprintf(stderr,
+					"Error - option '-t' needs a number as argument\n");
 			} else if (optopt == 'i') {
-				fprintf(stderr, "Error - option '-i' needs an interface as argument\n");
+				fprintf(stderr,
+					"Error - option '-i' needs an interface as argument\n");
 			} else if (optopt == 'w') {
 				read_opt |= CLR_CONT_READ;
 				break;
-			}
-			else
+			} else {
 				fprintf(stderr, "Error - unrecognised option: '-%c'\n", optopt);
+			}
 
 			return EXIT_FAILURE;
 		default:
@@ -136,15 +144,13 @@ int handle_debug_table(struct state *state, int argc, char **argv)
 		}
 	}
 
-	check_root_or_die("batctl");
-
 	if (read_opt & UNICAST_ONLY && read_opt & MULTICAST_ONLY) {
 		fprintf(stderr, "Error - '-u' and '-m' are exclusive options\n");
 		debug_table_usage(state);
 		return EXIT_FAILURE;
 	}
 
-	err = debug_table->netlink_fn(state , orig_iface, read_opt,
+	err = debug_table->netlink_fn(state, orig_iface, read_opt,
 				      orig_timeout, watch_interval);
 	return err;
 }
