@@ -58,6 +58,7 @@ static bool is_throughput_select_class(struct state *state)
 
 	return false;
 }
+
 static int parse_gw_limit(char *buff)
 {
 	char *slash_ptr;
@@ -68,7 +69,7 @@ static int parse_gw_limit(char *buff)
 		*slash_ptr = 0;
 
 	ret = parse_throughput(buff, "download gateway speed",
-				&gw_globals.bandwidth_down);
+			       &gw_globals.bandwidth_down);
 	if (!ret)
 		return -EINVAL;
 
@@ -132,7 +133,9 @@ static int parse_gw(struct state *state, int argc, char *argv[])
 		} else {
 			gw_globals.sel_class = strtoul(buff, &endptr, 0);
 			if (!endptr || *endptr != '\0') {
-				fprintf(stderr, "Error - unexpected argument for mode \"client\": %s\n", buff);
+				fprintf(stderr,
+					"Error - unexpected argument for mode \"client\": %s\n",
+					buff);
 				return -EINVAL;
 			}
 		}
@@ -168,8 +171,8 @@ static int print_gw(struct nl_msg *msg, void *arg)
 	int *result = arg;
 	const char *algo;
 	uint8_t gw_mode;
-	uint32_t val;
 	uint32_t down;
+	uint32_t val;
 	uint32_t up;
 
 	if (!genlmsg_valid_hdr(nlh, 0))
@@ -193,7 +196,7 @@ static int print_gw(struct nl_msg *msg, void *arg)
 		break;
 	case BATADV_GW_MODE_CLIENT:
 		if (missing_mandatory_attrs(attrs, mandatory_client,
-		    ARRAY_SIZE(mandatory_client)))
+					    ARRAY_SIZE(mandatory_client)))
 			return NL_OK;
 
 		algo = nla_data(attrs[BATADV_ATTR_ALGO_NAME]);
@@ -207,7 +210,7 @@ static int print_gw(struct nl_msg *msg, void *arg)
 		break;
 	case BATADV_GW_MODE_SERVER:
 		if (missing_mandatory_attrs(attrs, mandatory_server,
-		    ARRAY_SIZE(mandatory_server)))
+					    ARRAY_SIZE(mandatory_server)))
 			return NL_OK;
 
 		down = nla_get_u32(attrs[BATADV_ATTR_GW_BANDWIDTH_DOWN]);
@@ -279,7 +282,8 @@ static int gw_write_setting(struct state *state)
 
 static int gw_mode(struct state *state, int argc, char **argv)
 {
-	int optchar, res = EXIT_FAILURE;
+	int res = EXIT_FAILURE;
+	int optchar;
 
 	while ((optchar = getopt(argc, argv, "h")) != -1) {
 		switch (optchar) {
@@ -295,8 +299,6 @@ static int gw_mode(struct state *state, int argc, char **argv)
 	if (argc == 1)
 		return gw_read_setting(state);
 
-	check_root_or_die("batctl gw_mode");
-
 	res = parse_gw(state, argc, argv);
 	if (res < 0)
 		return EXIT_FAILURE;
