@@ -38,7 +38,6 @@ static void interface_usage(void)
 
 static int get_iface_status_netlink_parse(struct nl_msg *msg, void *arg)
 {
-
 	struct nlattr *attrs[NUM_BATADV_ATTR];
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	char *iface_status = arg;
@@ -75,7 +74,7 @@ static char *get_iface_status_netlink(struct state *state, unsigned int hardif,
 	iface_status[0] = '\0';
 
 	nl_cb_set(state->cb, NL_CB_VALID, NL_CB_CUSTOM, get_iface_status_netlink_parse,
-		iface_status);
+		  iface_status);
 
 	msg = nlmsg_alloc();
 	if (!msg)
@@ -118,9 +117,9 @@ static int print_interfaces_rtnl_parse(struct nl_msg *msg, void *arg)
 	struct state *state = arg;
 	struct ifinfomsg *ifm;
 	unsigned int master;
+	const char *status;
 	char *ifname;
 	int ret;
-	const char *status;
 
 	ifm = nlmsg_data(nlmsg_hdr(msg));
 	ret = nlmsg_parse(nlmsg_hdr(msg), sizeof(*ifm), attrs, IFLA_MAX,
@@ -277,9 +276,8 @@ static int create_interface(const char *mesh_iface,
 
 	msg = nlmsg_alloc_simple(RTM_NEWLINK,
 				 NLM_F_REQUEST | NLM_F_CREATE | NLM_F_EXCL | NLM_F_ACK);
-	if (!msg) {
+	if (!msg)
 		return -ENOMEM;
-	}
 
 	ret = nlmsg_append(msg, &rt_hdr, sizeof(rt_hdr), NLMSG_ALIGNTO);
 	if (ret < 0) {
@@ -341,9 +339,8 @@ static int destroy_interface(const char *mesh_iface)
 	int ret;
 
 	msg = nlmsg_alloc_simple(RTM_DELLINK, NLM_F_REQUEST | NLM_F_ACK);
-	if (!msg) {
+	if (!msg)
 		return -ENOMEM;
-	}
 
 	ret = nlmsg_append(msg, &rt_hdr, sizeof(rt_hdr), NLMSG_ALIGNTO);
 	if (ret < 0) {
@@ -375,9 +372,8 @@ static int set_master_interface(const char *iface, unsigned int ifmaster)
 	int ret;
 
 	msg = nlmsg_alloc_simple(RTM_SETLINK, NLM_F_REQUEST | NLM_F_ACK);
-	if (!msg) {
+	if (!msg)
 		return -ENOMEM;
-	}
 
 	ret = nlmsg_append(msg, &rt_hdr, sizeof(rt_hdr), NLMSG_ALIGNTO);
 	if (ret < 0) {
@@ -408,16 +404,17 @@ err_free_msg:
 static int interface(struct state *state, int argc, char **argv)
 {
 	struct interface_create_params create_params = {};
-	int i, optchar;
-	int ret;
-	unsigned int ifindex;
+	bool manual_mode = false;
 	unsigned int ifmaster;
+	unsigned int ifindex;
 	unsigned int pre_cnt;
 	const char *long_op;
 	unsigned int cnt;
-	int rest_argc;
 	char **rest_argv;
-	bool manual_mode = false;
+	int rest_argc;
+	int optchar;
+	int ret;
+	int i;
 
 	while ((optchar = getopt(argc, argv, "hM")) != -1) {
 		switch (optchar) {
@@ -439,8 +436,6 @@ static int interface(struct state *state, int argc, char **argv)
 	if (rest_argc == 0)
 		return print_interfaces(state);
 
-	check_root_or_die("batctl interface");
-
 	if ((strcmp(rest_argv[0], "add") != 0) && (strcmp(rest_argv[0], "a") != 0) &&
 	    (strcmp(rest_argv[0], "del") != 0) && (strcmp(rest_argv[0], "d") != 0) &&
 	    (strcmp(rest_argv[0], "create") != 0) && (strcmp(rest_argv[0], "c") != 0) &&
@@ -567,7 +562,8 @@ static int interface(struct state *state, int argc, char **argv)
 	if (!manual_mode && rest_argv[0][0] == 'd') {
 		cnt = count_interfaces(state->mesh_iface);
 		if (cnt == 0 && pre_cnt > 0)
-			fprintf(stderr, "Warning: %s has no interfaces and can be destroyed with: batctl meshif %s interface destroy\n",
+			fprintf(stderr,
+				"Warning: %s has no interfaces and can be destroyed with: batctl meshif %s interface destroy\n",
 				state->mesh_iface, state->mesh_iface);
 	}
 
