@@ -23,7 +23,6 @@
 #include <arpa/inet.h>
 
 #include "bat-hosts.h"
-#include "batadv_packet.h"
 #include "batman_adv.h"
 #include "netlink.h"
 #include "functions.h"
@@ -340,20 +339,20 @@ static const int info_hard_mandatory[] = {
 
 static int info_callback(struct nl_msg *msg, void *arg)
 {
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	struct print_opts *opts = arg;
 	const uint8_t *primary_mac;
+	uint16_t bla_group_id = 0;
+	const char *extra_header;
+	char *extra_info = NULL;
 	struct genlmsghdr *ghdr;
 	const uint8_t *mesh_mac;
 	const char *primary_if;
+	const char *algo_name;
 	const char *mesh_name;
 	const char *version;
-	char *extra_info = NULL;
 	uint8_t ttvn = 0;
-	uint16_t bla_group_id = 0;
-	const char *algo_name;
-	const char *extra_header;
 	int ret;
 
 	if (!genlmsg_valid_hdr(nlh, 0)) {
@@ -461,14 +460,14 @@ static int info_callback(struct nl_msg *msg, void *arg)
 
 char *netlink_get_info(struct state *state, uint8_t nl_cmd, const char *header)
 {
-	struct nl_msg *msg;
-	struct nl_cb *cb;
 	struct print_opts opts = {
 		.read_opt = 0,
 		.nl_cmd = nl_cmd,
 		.remaining_header = NULL,
 		.static_header = header,
 	};
+	struct nl_msg *msg;
+	struct nl_cb *cb;
 	int ret;
 
 	msg = nlmsg_alloc();
@@ -588,10 +587,10 @@ int netlink_print_common(struct state *state, char *orig_iface, int read_opt,
 		if (!last_err)
 			netlink_print_remaining_header(&opts);
 
-		if (!last_err && read_opt & (CONT_READ|CLR_CONT_READ))
+		if (!last_err && read_opt & (CONT_READ | CLR_CONT_READ))
 			usleep(1000000 * watch_interval);
 
-	} while (!last_err && read_opt & (CONT_READ|CLR_CONT_READ));
+	} while (!last_err && read_opt & (CONT_READ | CLR_CONT_READ));
 
 	bat_hosts_free();
 
@@ -690,10 +689,10 @@ struct translate_mac_netlink_opts {
 
 static int translate_mac_netlink_cb(struct nl_msg *msg, void *arg)
 {
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
+	struct translate_mac_netlink_opts *opts;
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	struct nlquery_opts *query_opts = arg;
-	struct translate_mac_netlink_opts *opts;
 	struct genlmsghdr *ghdr;
 	uint8_t *addr;
 	uint8_t *orig;
@@ -749,7 +748,7 @@ int translate_mac_netlink(struct state *state, const struct ether_addr *mac,
 
 	ret = netlink_query_common(state, state->mesh_ifindex,
 				   BATADV_CMD_GET_TRANSTABLE_GLOBAL,
-			           translate_mac_netlink_cb, NULL, NLM_F_DUMP,
+				   translate_mac_netlink_cb, NULL, NLM_F_DUMP,
 				   &opts.query_opts);
 	if (ret < 0)
 		return ret;
@@ -778,15 +777,15 @@ struct get_nexthop_netlink_opts {
 
 static int get_nexthop_netlink_cb(struct nl_msg *msg, void *arg)
 {
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	struct nlquery_opts *query_opts = arg;
 	struct get_nexthop_netlink_opts *opts;
 	struct genlmsghdr *ghdr;
-	const uint8_t *orig;
 	const uint8_t *neigh;
-	uint32_t index;
+	const uint8_t *orig;
 	const char *ifname;
+	uint32_t index;
 
 	opts = container_of(query_opts, struct get_nexthop_netlink_opts,
 			    query_opts);
@@ -855,7 +854,7 @@ int get_nexthop_netlink(struct state *state, const struct ether_addr *mac,
 
 	ret = netlink_query_common(state, state->mesh_ifindex,
 				   BATADV_CMD_GET_ORIGINATORS,
-			           get_nexthop_netlink_cb, NULL, NLM_F_DUMP,
+				   get_nexthop_netlink_cb, NULL, NLM_F_DUMP,
 				   &opts.query_opts);
 	if (ret < 0)
 		return ret;
@@ -878,12 +877,12 @@ struct get_primarymac_netlink_opts {
 
 static int get_primarymac_netlink_cb(struct nl_msg *msg, void *arg)
 {
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
+	struct get_primarymac_netlink_opts *opts;
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	struct nlquery_opts *query_opts = arg;
-	struct get_primarymac_netlink_opts *opts;
-	struct genlmsghdr *ghdr;
 	const uint8_t *primary_mac;
+	struct genlmsghdr *ghdr;
 
 	opts = container_of(query_opts, struct get_primarymac_netlink_opts,
 			    query_opts);
@@ -931,7 +930,7 @@ int get_primarymac_netlink(struct state *state, uint8_t *primarymac)
 
 	ret = netlink_query_common(state, state->mesh_ifindex,
 				   BATADV_CMD_GET_MESH_INFO,
-			           get_primarymac_netlink_cb, NULL, 0,
+				   get_primarymac_netlink_cb, NULL, 0,
 				   &opts.query_opts);
 	if (ret < 0)
 		return ret;
@@ -951,13 +950,13 @@ struct get_algoname_netlink_opts {
 
 static int get_algoname_netlink_cb(struct nl_msg *msg, void *arg)
 {
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
+	struct get_algoname_netlink_opts *opts;
+	struct nlmsghdr *nlh = nlmsg_hdr(msg);
+	struct nlquery_opts *query_opts = arg;
 	static const int mandatory[] = {
 		BATADV_ATTR_ALGO_NAME,
 	};
-	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
-	struct nlmsghdr *nlh = nlmsg_hdr(msg);
-	struct nlquery_opts *query_opts = arg;
-	struct get_algoname_netlink_opts *opts;
 	struct genlmsghdr *ghdr;
 	const char *algoname;
 
@@ -1007,7 +1006,7 @@ int get_algoname_netlink(struct state *state, unsigned int mesh_ifindex,
 	int ret;
 
 	ret = netlink_query_common(state, mesh_ifindex, BATADV_CMD_GET_MESH,
-			           get_algoname_netlink_cb, NULL, 0,
+				   get_algoname_netlink_cb, NULL, 0,
 				   &opts.query_opts);
 	if (ret < 0)
 		return ret;
