@@ -22,7 +22,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "batadv_packet.h"
 #include "batman_adv.h"
 #include "debug.h"
 #include "functions.h"
@@ -45,7 +44,7 @@ static const int routing_algos_mandatory[] = {
 
 static int routing_algos_callback(struct nl_msg *msg, void *arg __maybe_unused)
 {
-	struct nlattr *attrs[BATADV_ATTR_MAX+1];
+	struct nlattr *attrs[BATADV_ATTR_MAX + 1];
 	struct nlmsghdr *nlh = nlmsg_hdr(msg);
 	struct genlmsghdr *ghdr;
 	const char *algo_name;
@@ -81,11 +80,11 @@ static int routing_algos_callback(struct nl_msg *msg, void *arg __maybe_unused)
 
 static int print_routing_algos(struct state *state)
 {
-	struct nl_msg *msg;
-	struct nl_cb *cb;
 	struct print_opts opts = {
 		.callback = routing_algos_callback,
 	};
+	struct nl_msg *msg;
+	struct nl_cb *cb;
 
 	msg = nlmsg_alloc();
 	if (!msg)
@@ -152,8 +151,8 @@ static int print_ra_interfaces_rtnl_parse(struct nl_msg *msg, void *arg)
 {
 	struct print_ra_interfaces_rtnl_arg *print_arg = arg;
 	struct nlattr *attrs[IFLA_MAX + 1];
-	char algoname[256];
 	struct ifinfomsg *ifm;
+	char algoname[256];
 	char *mesh_iface;
 	int ret;
 
@@ -173,7 +172,7 @@ static int print_ra_interfaces_rtnl_parse(struct nl_msg *msg, void *arg)
 	if (ret < 0)
 		goto err;
 
-	if(!print_arg->header_shown) {
+	if (!print_arg->header_shown) {
 		print_arg->header_shown = true;
 		printf("Active routing protocol configuration:\n");
 	}
@@ -217,7 +216,7 @@ static int print_ra_interfaces(struct state *state)
 	}
 
 	nl_cb_set(cb, NL_CB_VALID, NL_CB_CUSTOM, print_ra_interfaces_rtnl_parse,
-		 &print_arg);
+		  &print_arg);
 
 	msg = nlmsg_alloc_simple(RTM_GETLINK, NLM_F_REQUEST | NLM_F_DUMP);
 	if (!msg) {
@@ -265,8 +264,8 @@ err_free_sock:
 
 static int routing_algo(struct state *state, int argc, char **argv)
 {
-	int optchar;
 	int res = EXIT_FAILURE;
+	int optchar;
 	int ret;
 
 	while ((optchar = getopt(argc, argv, "h")) != -1) {
@@ -280,8 +279,6 @@ static int routing_algo(struct state *state, int argc, char **argv)
 		}
 	}
 
-	check_root_or_die("batctl routing_algo");
-
 	if (argc == 2)
 		return write_default_ra(SYS_SELECTED_RA_PATH, argv[1]);
 
