@@ -6,7 +6,6 @@
  * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
-
 #include <unistd.h>
 #include <stdio.h>
 #include <stdbool.h>
@@ -71,8 +70,8 @@ int sys_simple_nlquery(struct state *state, enum batadv_nl_commands nl_cmd,
 		       nl_recvmsg_msg_cb_t attribute_cb,
 		       nl_recvmsg_msg_cb_t callback)
 {
-	int result;
 	struct nl_msg *msg;
+	int result;
 	int ret;
 
 	if (!state->sock)
@@ -147,26 +146,26 @@ int sys_simple_print_boolean(struct nl_msg *msg, void *arg,
 
 static void settings_usage(struct state *state)
 {
-	const char *default_prefixes[] = {
+	static const char * const default_prefixes[] = {
 		"",
 		NULL,
 	};
-	const char *meshif_prefixes[] = {
+	static const char * const meshif_prefixes[] = {
 		"meshif <netdev> ",
 		NULL,
 	};
-	const char *vlan_prefixes[] = {
+	static const char * const vlan_prefixes[] = {
 		"vlan <vdev> ",
 		"meshif <netdev> vid <vid> ",
 		NULL,
 	};
-	const char *hardif_prefixes[] = {
+	static const char * const hardif_prefixes[] = {
 		"hardif <netdev> ",
 		NULL,
 	};
 	const char *linestart = "Usage:";
-	const char **prefixes;
-	const char **prefix;
+	const char * const *prefixes;
+	const char * const *prefix;
 
 	switch (state->cmd->type) {
 	case SUBCOMMAND_MIF:
@@ -246,8 +245,6 @@ int handle_sys_setting(struct state *state, int argc, char **argv)
 	if (argc == 1)
 		return sys_read_setting(state);
 
-	check_root_or_die("batctl");
-
 	if (settings->parse) {
 		res = settings->parse(state, argc, argv);
 		if (res < 0)
