@@ -6,8 +6,6 @@
  * License-Filename: LICENSES/preferred/GPL-2.0
  */
 
-
-
 #include <netinet/in.h>
 #include <netinet/if_ether.h>
 #include <errno.h>
@@ -20,20 +18,18 @@
 #include <sys/select.h>
 #include <sys/time.h>
 
-#include "batadv_packet.h"
+#include "batadv_packet_compat.h"
 #include "main.h"
 #include "functions.h"
 #include "bat-hosts.h"
 #include "icmp_helper.h"
 
-
 #define TTL_MAX 50
 #define NUM_PACKETS 3
 
-
 static void traceroute_usage(void)
 {
-	fprintf(stderr, "Usage: batctl [options] traceroute [parameters] mac|bat-host|host_name|IPv4_address \n");
+	fprintf(stderr, "Usage: batctl [options] traceroute [parameters] mac|bat-host|host_name|IPv4_address\n");
 	fprintf(stderr, "parameters:\n");
 	fprintf(stderr, " \t -h print this help\n");
 	fprintf(stderr, " \t -n don't convert addresses to bat-host names\n");
@@ -42,16 +38,25 @@ static void traceroute_usage(void)
 
 static int traceroute(struct state *state, int argc, char **argv)
 {
-	struct batadv_icmp_packet icmp_packet_out, icmp_packet_in;
-	struct bat_host *bat_host;
+	struct batadv_icmp_packet icmp_packet_out;
+	struct batadv_icmp_packet icmp_packet_in;
 	struct ether_addr *dst_mac = NULL;
-	struct timeval tv;
-	ssize_t read_len;
-	char *dst_string, *mac_string, *return_mac, dst_reached = 0;
-	int ret = EXIT_FAILURE, res, i;
-	int found_args = 1, optchar, seq_counter = 0, read_opt = USE_BAT_HOSTS;
 	double time_delta[NUM_PACKETS];
 	int disable_translate_mac = 0;
+	int read_opt = USE_BAT_HOSTS;
+	struct bat_host *bat_host;
+	int ret = EXIT_FAILURE;
+	char dst_reached = 0;
+	int seq_counter = 0;
+	int found_args = 1;
+	struct timeval tv;
+	ssize_t read_len;
+	char *dst_string;
+	char *mac_string;
+	char *return_mac;
+	int optchar;
+	int res;
+	int i;
 
 	while ((optchar = getopt(argc, argv, "hnT")) != -1) {
 		switch (optchar) {
@@ -78,8 +83,6 @@ static int traceroute(struct state *state, int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
-	check_root_or_die("batctl traceroute");
-
 	dst_string = argv[found_args];
 	bat_hosts_init(read_opt);
 	bat_host = bat_hosts_find_by_name(dst_string);
@@ -91,7 +94,9 @@ static int traceroute(struct state *state, int argc, char **argv)
 		dst_mac = resolve_mac(dst_string);
 
 		if (!dst_mac) {
-			fprintf(stderr, "Error - mac address of the ping destination could not be resolved and is not a bat-host name: %s\n", dst_string);
+			fprintf(stderr,
+				"Error - mac address of the ping destination could not be resolved and is not a bat-host name: %s\n",
+				dst_string);
 			goto out;
 		}
 	}
@@ -112,7 +117,7 @@ static int traceroute(struct state *state, int argc, char **argv)
 	icmp_packet_out.reserved = 0;
 
 	printf("traceroute to %s (%s), %d hops max, %zu byte packets\n",
-		dst_string, mac_string, TTL_MAX, sizeof(icmp_packet_out));
+	       dst_string, mac_string, TTL_MAX, sizeof(icmp_packet_out));
 
 	for (icmp_packet_out.ttl = 1;
 	     !dst_reached && icmp_packet_out.ttl < TTL_MAX;
@@ -125,10 +130,11 @@ static int traceroute(struct state *state, int argc, char **argv)
 			time_delta[i] = 0.0;
 
 			res = icmp_interface_write(state,
-					   (struct batadv_icmp_header *)&icmp_packet_out,
-					   sizeof(icmp_packet_out));
+						   (struct batadv_icmp_header *)&icmp_packet_out,
+						   sizeof(icmp_packet_out));
 			if (res < 0) {
-				fprintf(stderr, "Error - can't send icmp packet: %s\n", strerror(-res));
+				fprintf(stderr, "Error - can't send icmp packet: %s\n",
+					strerror(-res));
 				continue;
 			}
 
@@ -145,7 +151,7 @@ read_packet:
 
 			if ((size_t)read_len < sizeof(icmp_packet_in)) {
 				printf("Warning - dropping received packet as it is smaller than expected (%zu): %zd\n",
-					sizeof(icmp_packet_in), read_len);
+				       sizeof(icmp_packet_in), read_len);
 				continue;
 			}
 
