@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: GPL-2.0
-/* Copyright (C) 2007-2020  B.A.T.M.A.N. contributors:
+/* Copyright (C) B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <mareklindner@neomailbox.ch>
  *
@@ -13,7 +13,6 @@
 #include "functions.h"
 #include "bat-hosts.h"
 
-
 static void translate_usage(void)
 {
 	fprintf(stderr, "Usage: batctl [options] translate mac|bat-host|host_name|IPv4_address\n");
@@ -24,7 +23,8 @@ static int translate(struct state *state, int argc, char **argv)
 	struct ether_addr *dst_mac = NULL;
 	struct bat_host *bat_host;
 	int ret = EXIT_FAILURE;
-	char *dst_string, *mac_string;
+	char *dst_string;
+	char *mac_string;
 
 	if (argc <= 1) {
 		fprintf(stderr, "Error - destination not specified\n");
@@ -32,8 +32,6 @@ static int translate(struct state *state, int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
-	check_root_or_die("batctl translate");
-
 	dst_string = argv[1];
 	bat_hosts_init(0);
 	bat_host = bat_hosts_find_by_name(dst_string);
@@ -45,12 +43,14 @@ static int translate(struct state *state, int argc, char **argv)
 		dst_mac = resolve_mac(dst_string);
 
 		if (!dst_mac) {
-			fprintf(stderr, "Error - mac address of the ping destination could not be resolved and is not a bat-host name: %s\n", dst_string);
+			fprintf(stderr,
+				"Error - mac address of the ping destination could not be resolved and is not a bat-host name: %s\n",
+				dst_string);
 			goto out;
 		}
 	}
 
-	dst_mac = translate_mac(state->mesh_iface, dst_mac);
+	dst_mac = translate_mac(state, dst_mac);
 	if (dst_mac) {
 		mac_string = ether_ntoa_long(dst_mac);
 		printf("%s\n", mac_string);
@@ -64,5 +64,6 @@ out:
 	return ret;
 }
 
-COMMAND(SUBCOMMAND_MIF, translate, "t", COMMAND_FLAG_MESH_IFACE, NULL,
+COMMAND(SUBCOMMAND_MIF, translate, "t",
+	COMMAND_FLAG_MESH_IFACE | COMMAND_FLAG_NETLINK, NULL,
 	"<destination>     \ttranslate a destination to the originator responsible for it");
